@@ -66,6 +66,23 @@ class RequestField(RequestFieldBase):
             return False
         return self.__dict__ == other.__dict__
 
+def DeprecationWarningOnce(func=None, *, prefix=None):
+    def decorator(func):
+        warned = False
+        def wrapper(instance, *args, **kwargs):
+            nonlocal warned
+            if not warned:
+                msg = f"{func.__name__} is deprecated"
+                if prefix:
+                    msg = f"{prefix}.{msg}"
+                instance.api_client.configuration.logger.warning(msg)
+                warned = True
+            return func(instance, *args, **kwargs)
+        return wrapper
+    if func is None:
+        return decorator
+    else:
+        return decorator(func)
 
 class JSONEncoder(json.JSONEncoder):
     compact_separators = (',', ':')
@@ -1137,7 +1154,7 @@ class ApiClient:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'Konfig/10.32.0/python'
+        self.user_agent = 'Konfig/10.32.2/python'
 
     def __enter__(self):
         return self
